@@ -1044,9 +1044,20 @@ testsetup <- function() {
 
 }
 
+dns_lookup <- function(host = "captive.apple.com") {
+  con <- try(
+    socketConnection(host, port = 80, open = "r+", timeout = 2),
+    silent = TRUE
+  )
+  on.exit(close(con))
+
+  if (inherits(con, "try-error")) return(FALSE)
+
+  TRUE
+}
+
 # testthat::skip_if_offline requires curl, but fails if curl is not available
 skip_online_checks <- function() {
   testthat::skip_on_cran()
-  testthat::skip_if_not_installed("curl")
-  testthat::skip_if_offline()
+  testthat::skip_if_not(dns_lookup())
 }
